@@ -4,6 +4,7 @@
 """
 
 import logging
+from abc import ABC
 
 from amocrm.api.base.api_loader_base import AmocrmApiLoaderBase
 
@@ -16,6 +17,8 @@ def process_json(data, entity):
     Args:
         data: row data json
     Returns: list
+    :param data:
+    :param entity:
     """
     if entity in ("leads", "companies", "contacts", "tasks"):
         items = data["_embedded"]["items"]
@@ -26,7 +29,7 @@ def process_json(data, entity):
     return items
 
 
-class AmocrmApiLoader(AmocrmApiLoaderBase):
+class AmocrmApiLoader(AmocrmApiLoaderBase, ABC):
     """
     main class
     """
@@ -72,7 +75,7 @@ class AmocrmApiLoader(AmocrmApiLoaderBase):
         params = {}
         headers = {}
         while cur_offset < PAGE_NUMBER_MAX and count_uploaded == self.batch_api:
-            file_path = self.get_file_name(cur_offset, self.batch_api)
+            file_path = self.get_file_name(cur_offset, self.batch_api, 0)
             self.logger.info("Extracting page number %d ", cur_offset)
             if self.date_modified_from is not None:
                 self.logger.info(
@@ -89,7 +92,7 @@ class AmocrmApiLoader(AmocrmApiLoaderBase):
             try:
                 count_uploaded = len(process_json(objects.json(), self.entity))
                 self.logger.info(
-                    "Saving data in file %s, count rows %d, total: %d",
+                    "Saving data to the file %s, count rows %d, total: %d",
                     file_path,
                     count_uploaded,
                     self.rows_to_upload,
